using System;
using System.Drawing;
using MonoTouch.Foundation;
using MonoTouch.UIKit;
using System.Collections.Generic;
using MonoTouch.ObjCRuntime;
using Infragistics;

namespace ColumnSeriesCustomization
{
	public partial class ColumnSeriesCustomizationViewController : UIViewController
	{
		List<NSObject> _data = new List<NSObject>();
		IGChartView _chart = new IGChartView();
		IGLegend _legend = new IGLegend();
		IGCategorySeriesDataSourceHelper _sourceChrome, _sourceFirefox, _sourceIE, _sourceSafari;

		public ColumnSeriesCustomizationViewController ()
		{
		}

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();

			this.View.BackgroundColor = UIColor.White;
			PopulateData (5);

			_chart = new IGChartView();
			_chart.Frame = new RectangleF (0, 50, this.View.Bounds.Width, this.View.Bounds.Height - 50);
			_chart.Frame.Inflate (-5.0f, -5.0f);
			_chart.AutoresizingMask = UIViewAutoresizing.FlexibleWidth|UIViewAutoresizing.FlexibleHeight;
			this.View.Add (_chart);

			_legend = new IGLegend(IGChartLegendType.IGChartLegendTypeSeries);
			_legend.Layer.BorderColor = UIColor.Gray.CGColor;
			_legend.Layer.BorderWidth = 2;
			_legend.Frame = new RectangleF(5, 5, this.View.Bounds.Width - 10, 40);
			_legend.AutoresizingMask = UIViewAutoresizing.FlexibleWidth|UIViewAutoresizing.FlexibleHeight;
			_legend.Orientation = IGOrientation.IGOrientationHorizontal;
			_legend.HorizontalAlignment = IGHorizontalAlign.IGHorizontalAlignCenter;
			_legend.VerticalAlignment = IGVerticalAlign.IGVerticalAlignCenter;
			_chart.Legend = _legend;
			this.View.Add(_legend);

			_sourceChrome = new IGCategorySeriesDataSourceHelper (_data.ToArray (), "ChromeBrowser");
			_sourceChrome.LabelPath = "Country";
			_sourceFirefox = new IGCategorySeriesDataSourceHelper (_data.ToArray (), "FirefoxBrowser");
			_sourceFirefox.LabelPath = "Country";
			_sourceIE = new IGCategorySeriesDataSourceHelper (_data.ToArray (), "IEBrowser");
			_sourceIE.LabelPath = "Country";
			_sourceSafari = new IGCategorySeriesDataSourceHelper (_data.ToArray (), "SafariBrowser");
			_sourceSafari.LabelPath = "Country";

			IGColumnSeries seriesChrome = _chart.AddSeries (new Class ("IGColumnSeries"), "seriesChrome", _sourceChrome, "xAxis", "yAxis") as IGColumnSeries;
			seriesChrome.XAxis.Extent = 40;
			seriesChrome.Title = "Chrome";

			IGColumnSeries seriesFirefox = _chart.AddSeries (new Class ("IGColumnSeries"), "seriesFirefox", _sourceFirefox, "xAxis", "yAxis") as IGColumnSeries;
			seriesFirefox.Title = "Firefox";

			IGColumnSeries seriesIE = _chart.AddSeries (new Class ("IGColumnSeries"), "seriesIE", _sourceIE, "xAxis", "yAxis") as IGColumnSeries;
			seriesIE.Title = "IE";

			IGColumnSeries seriesSafari = _chart.AddSeries (new Class ("IGColumnSeries"), "seriesSafari", _sourceSafari, "xAxis", "yAxis") as IGColumnSeries;
			seriesSafari.Title = "Safari";
		}

		public void PopulateData(int totalItems)
		{
			_data.Clear();

			for (int i = 0; i <= totalItems; i++) {
				bool containsCountry = false;
				WebVisitorItem webVisitor = new WebVisitorItem ();
				foreach (WebVisitorItem item in _data) {
					if (item.Country == webVisitor.Country)
					{
						containsCountry = true;
						break;
					}
				}

				if (!containsCountry)
					_data.Add (webVisitor);
			}

			if (_data.Count == 1)
				PopulateData (totalItems);
		}
	}
}

